@@ -1,8 +1,5 @@
 package Job::Machine::DB;
-BEGIN {
-  $Job::Machine::DB::VERSION = '0.18';
-}
-
+$Job::Machine::DB::VERSION = '0.19';
 use strict;
 use warnings;
 use Carp qw/croak confess/;
@@ -89,38 +86,22 @@ sub fetch_work_task {
 	$self->{current_table} = 'task';
 	my $elems = join(',', ('?') x @$queue);
 	my $sql = qq{
-		UPDATE
-			"$self->{schema}".$self->{current_table} t
-		SET
-			status=100,
+		UPDATE "$self->{schema}".$self->{current_table} t
+		SET status=100,
 			modified=default
-		FROM
-			"jobmachine".class cx
-		WHERE
-			t.class_id = cx.class_id
-		AND
-			task_id = (
-				SELECT
-					min(task_id)
-				FROM
-					"$self->{schema}".$self->{current_table} t
-				JOIN
-					"jobmachine".class c
-				USING
-					(class_id)
-				WHERE
-					t.status=0
-				AND
-					c.name IN ($elems)
-				AND
-					t.run_after IS NULL
-				OR
-					t.run_after > now()
-			)
-		AND
-			t.status=0
-		RETURNING
-			*
+		FROM "jobmachine".class cx
+		WHERE t.class_id = cx.class_id
+		AND task_id = (
+			SELECT min(task_id)
+			FROM "$self->{schema}".$self->{current_table} t
+			JOIN "jobmachine".class c USING (class_id)
+			WHERE t.status=0
+			AND c.name IN ($elems)
+			AND (t.run_after IS NULL
+			OR t.run_after > now())
+		)
+		AND t.status=0
+		RETURNING *
 		;
 	};
 	my $task = $self->select_first(
@@ -139,13 +120,10 @@ sub insert_task {
 	$self->{current_table} = 'task';
 	my $frozen = $self->json->encode($data);
 	my $sql = qq{
-		INSERT INTO
-			"$self->{schema}".$self->{current_table}
+		INSERT INTO "$self->{schema}".$self->{current_table}
 			(class_id,parameters,status)
-		VALUES
-			(?,?,?)
-		RETURNING
-			task_id
+		VALUES (?,?,?)
+		RETURNING task_id
 	};
 	$self->insert(sql => $sql,data => [$class->{class_id},$frozen,0]);
 }
@@ -155,12 +133,9 @@ sub set_task_status {
 	my $id = $self->task_id;
 	$self->{current_table} = 'task';
 	my $sql = qq{
-		UPDATE
-			"$self->{schema}".$self->{current_table}
-		SET
-			status=?
-		WHERE 
-			task_id=?
+		UPDATE "$self->{schema}".$self->{current_table}
+		SET status=?
+		WHERE task_id=?
 	};
 	$self->update(sql => $sql,data => [$status,$id]);
 }
@@ -169,12 +144,9 @@ sub fetch_class {
 	my ($self,$queue) = @_;
 	$self->{current_table} = 'class';
 	my $sql = qq{
-		SELECT
-			*
-		FROM
-			"$self->{schema}".$self->{current_table}
-		WHERE
-			name=?
+		SELECT *
+		FROM "$self->{schema}".$self->{current_table}
+		WHERE name=?
 	};
 	return $self->select_first(sql => $sql,data => [$queue]) || $self->insert_class($queue);
 }
@@ -182,13 +154,10 @@ sub fetch_class {
 sub insert_class {
 	my ($self,$queue) = @_;
 	my $sql = qq{
-		INSERT INTO
-			"$self->{schema}".$self->{current_table}
+		INSERT INTO "$self->{schema}".$self->{current_table}
 			(name)
-		VALUES
-			(?)
-		RETURNING
-			class_id
+		VALUES (?)
+		RETURNING class_id
 	};
 	$self->select_first(sql => $sql,data => [$queue]);
 }
@@ -198,13 +167,10 @@ sub insert_result {
 	$self->{current_table} = 'result';
 	my $frozen = $self->json->encode($data);
 	my $sql = qq{
-		INSERT INTO
-			"$self->{schema}".$self->{current_table}
+		INSERT INTO "$self->{schema}".$self->{current_table}
 			(task_id,result)
-		VALUES
-			(?,?)
-		RETURNING
-			result_id
+		VALUES (?,?)
+		RETURNING result_id
 	};
 	$self->insert(sql => $sql,data => [$self->{task_id},$frozen]);
 }
@@ -213,14 +179,10 @@ sub fetch_result {
 	my ($self,$id) = @_;
 	$self->{current_table} = 'result';
 	my $sql = qq{
-		SELECT
-			*
-		FROM
-			"$self->{schema}".$self->{current_table}
-		WHERE
-			task_id=?
-		ORDER BY
-			result_id DESC
+		SELECT *
+		FROM "$self->{schema}".$self->{current_table}
+		WHERE task_id=?
+		ORDER BY result_id DESC
 	};
 	my $result = $self->select_first(sql => $sql,data => [$id]) || return;
 
@@ -231,14 +193,10 @@ sub fetch_results {
 	my ($self,$id) = @_;
 	$self->{current_table} = 'result';
 	my $sql = qq{
-		SELECT
-			*
-		FROM
-			"$self->{schema}".$self->{current_table}
-		WHERE
-			task_id=?
-		ORDER BY
-			result_id DESC
+		SELECT *
+		FROM "$self->{schema}".$self->{current_table}
+		WHERE task_id=?
+		ORDER BY result_id DESC
 	};
 	my $results = $self->select_all(sql => $sql,data => [$id]) || return;
 
@@ -267,14 +225,10 @@ sub revive_tasks {
 	$self->{current_table} = 'task';
 	my $status = 100;
 	my $sql = qq{
-		UPDATE
-			"$self->{schema}".$self->{current_table}
-		SET
-			status=0
-		WHERE
-			status=?
-		AND
-			modified < now() - INTERVAL '$max seconds'
+		UPDATE "$self->{schema}".$self->{current_table}
+		SET status=0
+		WHERE status=?
+		AND modified < now() - INTERVAL '$max seconds'
 	};
 	my $result = $self->do(sql => $sql,data => [$status]);
 	return $result;
@@ -290,14 +244,10 @@ sub fail_tasks {
 	$self->{current_table} = 'result';
 	my $limit = 100;
 	my $sql = qq{
-		SELECT
-			task_id
-		FROM
-			"$self->{schema}".$self->{current_table}
-		GROUP BY
-			task_id
-		HAVING
-			count(*)>?
+		SELECT task_id
+		FROM "$self->{schema}".$self->{current_table}
+		GROUP BY task_id
+		HAVING count(*)>?
 		LIMIT ?
 	};
 	my $result = $self->select_all(sql => $sql,data => [$retries,$limit]) || return 0;
@@ -307,12 +257,9 @@ sub fail_tasks {
 	$self->{current_table} = 'task';
 	my $status = 900;
 	$sql = qq{
-		UPDATE
-			"$self->{schema}".$self->{current_table}
-		SET
-			status=?
-		WHERE
-			task_id IN ($task_ids)
+		UPDATE "$self->{schema}".$self->{current_table}
+		SET status=?
+		WHERE task_id IN ($task_ids)
 	};
 	$self->do(sql => $sql,data => [$status]);
 	return scalar @$result;
@@ -328,10 +275,8 @@ sub remove_tasks {
 	$self->{current_table} = 'task';
 	my $limit = 100;
 	my $sql = qq{
-		DELETE FROM
-			"$self->{schema}".$self->{current_table}
-		WHERE
-			modified < now() - INTERVAL '$after days'
+		DELETE FROM "$self->{schema}".$self->{current_table}
+		WHERE modified < now() - INTERVAL '$after days'
 	};
 	my $result = $self->do(sql => $sql,data => []);
 	return $result;
@@ -427,16 +372,19 @@ sub DESTROY {
 
 1;
 
+__END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Job::Machine::DB
 
 =head1 VERSION
 
-version 0.18
+version 0.19
 
 =head1 NAME
 
@@ -497,17 +445,24 @@ each row looks like this:
 
 =head1 AUTHOR
 
+Kaare Rasmussen <kaare@cpan.org>.
+
+=head1 COPYRIGHT
+
+Copyright (C) 2009,2014, Kaare Rasmussen
+
+This module is free software; you can redistribute it or modify it
+under the same terms as Perl itself.
+
+=head1 AUTHOR
+
 Kaare Rasmussen <kaare at cpan dot net>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2011 by Kaare Rasmussen.
+This software is copyright (c) 2014 by Kaare Rasmussen.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
-
-__END__
-
